@@ -32,7 +32,7 @@ __PACKAGE__->mk_accessors(qw (
 
 =head1 NAME
 
-Biber::Entry::Name
+Biber::Entry::Name - Biber::Entry::Name objects
 
 =head2 new
 
@@ -513,7 +513,7 @@ L<https://github.com/plk/biber/issues>.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2012 François Charette and Philip Kime, all rights reserved.
-Copyright 2012-2020 Philip Kime, all rights reserved.
+Copyright 2012-2022 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
